# Basic Logging Module

from TW.API import *
from Interfaces import *

import sys

__all__ = ['LogService','LogTarget','LogClient']


# Debug level constants

MSG_DEBUG = 1 << 0
MSG_WARN = 1 << 1
MSG_ERROR = 1 << 2
MSG_INFO = 1 << 3

LOG_MSG = {MSG_DEBUG: "DEBUG  ", MSG_WARN: "WARNING", MSG_ERROR: "ERROR  ", MSG_INFO: "INFO   "}

class LogService(SEF.Service):

	__implements__ = ILogService

	def __init__(self,fname=None):
		self._target = LogTarget()
		self._fname = fname

	def _write(self,priority,data):
		self._target.open(self._fname)
		self._target.write(priority,data)
		self._target.close()

	def _showmessage(self,priority,sender,message):
		self._write(priority,message)

	def debug(self,sender,message):
		self._showmessage(MSG_DEBUG,sender,message)

	def warn(self,sender,message):
		self._showmessage(MSG_WARN,sender,message)

	def error(self,sender,message):
		self._showmessage(MSG_ERROR,sender,message)

	def info(self,sender,message):
		self._showmessage(MSG_INFO,sender,message)

	def __del__(self):
		try:
			self._target.close()
		except:
			pass

class LogTarget(object):

	__implements__ = ILogTarget

	def open(self,fname=None):
		self._fd = sys.stdout

	def write(self,priority,data):
		self._fd.write("%s: %s\n" % (LOG_MSG[priority],data))

	def close(self):
		del self._fd
	
class LogClient(object):

	__implements__ = ILogClient

	log = SEF.bindTo('Logger')
	
setupModule()
